/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid library code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this dmraid library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#ifndef _DMRAID_H_
#define _DMRAID_H_

#include <sys/types.h>
#include "display/display.h"
#include "format/format.h"
#include "log/log.h"

/*
 * Library init/exit
 */
int libdmraid_init(int argc, char **argv);
void libdmraid_exit(void);

/*
 * Retrieve version identifiers.
 */
int dm_version(char *version, size_t size);
const char *libdmraid_version(void);

/*
 * Dealing with devices.
 */
int discover_disks(void);
void discover_rd(char *fmt, char **devices);
void discover_partitions(void);
unsigned int count_devices(enum dev_type type);
void free_all_disk_infos(void);

/*
 * Erase ondisk metadata.
 */
int erase_metadata(void);

/*
 * Dealing with formats.
 */
void *get_format_list(void);
void *get_format(void **iter, enum fmt_type type);
const char *get_format_name(void *fmt);

/*
 * Dealing with RAID sets.
 */
struct list_head *default_set_list(void);
void *start_set_list(void);
void *get_set(void **iter);
const char *get_set_level(void *rs);
const char *get_set_name(void *rs);
int build_set(char *name);
unsigned int count_sets(void);
int write_set(void *rs);
int activate_set(void *rs);
int deactivate_set(void *rs);
int partitioned_set(void *rs);
int base_partitioned_set(void *rs);
void free_all_sets(void);

/*
 * Miscelanious (command name, debug level, ...
 */
char *cmd(void);
int inc_column(void);
int column(void);
int inc_debug(void);
int debug(void);
int inc_dump(void);
int dump(void);
int inc_verbose(void);
int verbose(void);
int inc_test(void);
int test(void);

#endif
