/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this dmraid library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#ifndef _LOG_H_
#define _LOG_H_

#include <stdio.h>

/* Compatibility type for logging. */
#define	PRIzu	"zu"

#define __log(FILE, x...) do { fprintf(FILE, x); fputc('\n', FILE);} while(0)

#if 1
#  define log_line(FILE) \
	do { \
		fprintf(FILE, "DBG: %s[%d] ", __FILE__, __LINE__); \
	} while (0)

#  define log_dbg(level, x...) \
	do { \
		if (debug() >= level) { \
			log_line(stderr); \
			fprintf(stderr, x); \
			fputc('\n', stderr); \
		} \
	} while(0)
#else
#  define	log_dbg(x...)
#endif

#define log_debug(level, x...)	log_dbg(level, x)

#define log_err(x...)		__log(stderr, x)
#define log_error(x...)		log_err(x)
#define	LOG_ERR(ret, x...)	do { log_err(x); return ret; } while (0)

#define log_print(x...)		__log(stdout, x)
#define	LOG_PRINT(ret, x...)	do { log_print(x); return ret; } while (0)

#define log_verbose(level, x...) \
	do { \
		if (verbose() >= level) \
			log_print(x); \
	} while (0)

#endif
