/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this dmraid library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#include <stdarg.h>
#include "internal.h"
#include "misc.h"
#include "version.h"

/* Command name we're called by. */
static char *_cmd = NULL;
char *cmd(void)
{
	return _cmd;
}

void init_cmd(int argc, char **argv)
{
	_cmd = strrchr(argv[0], '/');
	_cmd = _cmd ? _cmd + 1 : argv[0];
}

/* Column output. */
static int _column = 0;
int inc_column(void)
{
	return ++_column;
}

int column(void)
{
	return _column;
}

/* Debug level. */
static int _debug = 0;
int inc_debug(void)
{
	return ++_debug;
}

int debug(void)
{
	return _debug;
}

/* Debug level. */
static int _dump = 0;
int inc_dump(void)
{
	return ++_dump;
}

int dump(void)
{
	return _dump;
}

/* Test run. */
static int _test = 0;
int inc_test(void)
{
	return ++_test;
}

int test(void)
{
	return _test;
}

/* Verbosity level. */
static int _verbose = 0;
int inc_verbose(void)
{
	return ++_verbose;
}

int verbose(void)
{
	return _verbose;
}

/* Convert a numeric string into ascii */
void mk_alpha(char *str)
{
	char *s;
	static char asc[] = "abcdefghij";
	static char buf[2] = { '\0', '\0' };

	for (s = str; *s; s++) {
		if (isdigit(*s)) {
			buf[0] = *s;
			*s = asc[atoi(buf)];
		}
	}
}

/* Return library version. */
const char *libdmraid_version(void)
{
	return DMRAID_LIB_VERSION;
}

/* Prompt for a yes/no answer */
int yes_no_prompt(const char *prompt, ...)
{
	int c = 0;
	va_list ap;

	while (c != 'y' && c != 'n') {
		if (c == '\n' || c == 0) {
			va_start(ap, prompt);
			vprintf(prompt, ap);
			va_end(ap);
			printf(" ? [y/n] :");
		}
		c = tolower(getchar());
	}

	while (getchar() != '\n') ;

	return (c == 'y') ? 1 : 0;
}
