/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this dmraid library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#include <stdio.h>
#include <malloc.h>
#include <sys/types.h>
#include "dbg_malloc.h"
#include "log/log.h"
#include "misc/misc.h"

#define DBG_LEVEL	4

void *dbg_malloc(size_t size)
{
	void *ret = malloc(size);

	if (ret)
		log_dbg(DBG_LEVEL,
			"dbg_malloc: Allocated %zu bytes", size);
	else
		log_dbg(DBG_LEVEL,
			"dbg_malloc: FAILED allocating %zu bytes",
			size);
			
	return ret;
}

void *dbg_realloc(void *ptr, size_t size)
{
	void *ret;

	if (debug() >= DBG_LEVEL) {
		if (!ptr)
			log_dbg(DBG_LEVEL, "dbg_realloc: NULL pointer!");
		if (!size)
			log_dbg(DBG_LEVEL, "dbg_realloc: ZERO size!");
	}

	if ((ret = realloc(ptr, size)))
		log_dbg(DBG_LEVEL,
			"dbg_realloc: reallocated %zu bytes", size);
	else
		log_dbg(DBG_LEVEL,
			"dbg_realloc: FAILED reallocating %zu bytes",
			size);
			
	return ret;
}

void dbg_free(void *ptr)
{
	if (ptr)
		log_dbg(DBG_LEVEL,
			"dbg_free: Freeing 0x%x", (unsigned int) ptr);
	else
		log_dbg(DBG_LEVEL, "dbg_free: NULL pointer!");

	free(ptr);
}
