/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this dmraid code; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

#ifndef	_COMMANDS_H
#define	_COMMANDS_H

/* Actions dmraid performs */
enum action {
	UNDEF		= 0x0,
	ACTIVATE	= 0x1,
	DEACTIVATE	= 0x2,
	FORMAT		= 0x4,
#ifndef	DMRAID_MINI
	BLOCK_DEVICES	= 0x8,
	COLUMN		= 0x10,
	DBG		= 0x20,
	DUMP		= 0x40,
	ERASE		= 0x80,
	HELP		= 0x100,
	LIST_FORMATS	= 0x200,
#  ifdef	DMRAID_NATIVE_LOG
	NATIVE_LOG	= 0x400,
#  endif
	NO_PARTITIONS	= 0x800,
	RAID_DEVICES	= 0x1000,
	SETS		= 0x2000,
	TEST		= 0x4000,
	VERBOSE		= 0x8000,
	ACTIVE		= 0x10000,
	INACTIVE	= 0x20000,
	VERSION		= 0x40000,
#endif
};

extern enum action action;

/*
 * Action flag definitions for set_action().
 *
 * 'Early' options can be handled directly in set_action() by calling
 * the functions registered here (set on_set member).
 */
struct actions {
	char option;		/* Char of short optione */
	unsigned char args;	/* Arguments allowed ? */
	unsigned char alone;	/* Can be set w/o other options */
	enum action action;	/* action flag */
	unsigned char on_set;	/* Call function when setting flag(s) */
	int (*func)(void);	/* Function to call in case of hit or NULL */
	enum action allowed;	/* Allowed flags (ie, other options) */
};

/* 
 * Pre and Post functions to perform for an action.
 */
struct prepost {
	enum action action;
	int (*pre)(void *);
	int (*post)(void *, int arg);
};

int handle_args(int argc, char ***argv, int *end);
int perform(void *rs);

#endif
