/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this dmraid code; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

/*
 * There's a function call abstraction in here called perform().
 * See commands.[ch] for details.
 */

#include <dmraid.h>
#include "commands.h"
#include "toollib.h"
#include "version.h"

int main(int argc, char **argv)
{
	int end = 0, ret = 1;

	if (!libdmraid_init(argc, argv))
		return 1;

	/*
	 * Parse command line arguments and handle all
	 * options *not* in need of any metadata.
	 */
	if (!handle_args(argc, &argv, &end))
		return 1;

	if (end) /* No io needed (eg, help). */
		return 0;

	/* Discover disks and keep disk metadata (ie. geometry and size) */
	if (!discover_disks())
		return 1;

	if (!count_devices(DEVICE))
		LOG_PRINT(0, "No disks found\n");

#ifndef DMRAID_MINI
	/* We only need discovered disks to perform this */
	if (BLOCK_DEVICES & action) {
		ret = perform(NULL);
		goto out;
	}

	/* Discover RAID disks and keep RAID metadata (eg, hpt45x) */
	discover_rd(format, ((NATIVE_LOG|RAID_DEVICES) & action) ? argv : NULL);
#else
	discover_rd(format, NULL);
#endif
	if (!count_devices(RAID)) {
		log_print(format ? "No RAID disks with format \"%s\"\n" :
				   "No RAID disks",
			  format);
		goto out;
	}

#ifndef DMRAID_MINI
	/* Erase metadata */
	if (ERASE & action) {
		ret = perform(NULL);
		goto out;
	}

#  ifdef DMRAID_NATIVE_LOG
	if ((NATIVE_LOG|RAID_DEVICES) & action) {
#  else
	if ((RAID_DEVICES) & action) {
#  endif
		/* Log/list RAID devices discovered */
		ret = perform(NULL);
		goto out;
	}
#endif

	/* Group RAID sets. */
	build_sets(argv);
	if (!count_sets()) {
		log_print( format ? "No RAID sets with format \"%s\"\n" :
				   "No RAID sets",
			  format);
		goto out;
	}

	if (DEACTIVATE & action) {
		/*
		 * Discover any partitions to deactivate
		 * RAID sets for and work on them.
		 */
		discover_partitions();
		work_on_sets(1);
	}

	/* Work on the non-partitioned sets. */
	work_on_sets(0);

	if (!(NO_PARTITIONS & action) &&
	    ((ACTIVATE|SETS) & action)) {
		/*
		 * Discover any partitions to activate
		 * RAID sets for and work on them.
		 */
		discover_partitions();
		work_on_sets(1);
	}

  out:
	free_all_sets();
	free_all_disk_infos();
	libdmraid_exit();

	return (ret ? 0 : 1);
}
