/*
 * Copyright (C) 2004  Heinz Mauelshagen, Red Hat GmbH. All rights reserved.
 *
 * This dmraid code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * dmraid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this dmraid code; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA
 */

/*
 * Tool library
 */

#include "commands.h"
#include "toollib.h"
#include <dmraid.h>
#include <ctype.h>
#include <getopt.h>
#include <string.h>

/* Build all sets or the ones given. */
void build_sets(char **sets)
{
	int o = 0;

	do {
		if (!build_set(sets[o]))
			log_err("Failed building set\n");

		if (!sets[o])
			break;
	} while (sets[++o]);
}

/* Convert a character sting to lower case. */
void str_tolower(char *s)
{
	for (; *s; s++)
		*s = tolower(*s);
}

/* Check if a special/all formats shall be used to read the metadata. */
int valid_format(char *name)
{
	void *iter, *fmt;

	for (iter = get_format_list(); (fmt = get_format(&iter, FMT_RAID)); ) {
		if (!strcmp(name, get_format_name(fmt)))
			return 1;
	}

	return 0;
}

/* Work on all sets in the list. */
void work_on_sets(int partitions)
{
	void *iter, *rs;

	for (iter = start_set_list(); (rs = get_set(&iter)); ) {
		if (partitions) {
			if (partitioned_set(rs) && !base_partitioned_set(rs))
				perform(rs);
		} else if (!partitioned_set(rs))
			perform(rs);
	}
}
